@@ -7,7 +7,7 @@ knitr::opts_chunk$set(
 )
 
 ## -----------------------------------------------------------------------------
-# devtools::install_github("pbiecek/DALEX")
+# devtools::install_github("ModelOriented/DALEX")
 library(DALEX)
 library(iBreakDown)
 
@@ -60,15 +60,24 @@ bd_svm <- local_attributions(m_svm,
 plot(bd_svm)
 
 ## -----------------------------------------------------------------------------
-library(caret)
+library("xgboost")
 
-m_knn <- knnreg(life_length ~ . , data = dragons)
+model_matrix <- model.matrix(life_length ~ . -1, dragons)
+data <- xgb.DMatrix(model_matrix, label = dragons$life_length)
 
-bd_knn <- local_attributions(m_knn,
-                            data = dragons_test,
-                            new_observation =  new_observation)
+params <- list(max_depth = 2, eta = 1, silent = 1, nthread = 2, eval_metric = "rmse")
 
-plot(bd_knn)
+m_xgboost <- xgb.train(params, data, nrounds = 50)
+
+test_matrix <- model.matrix(life_length ~ . -1, dragons_test)
+observation_matrix <- test_matrix[1,,drop=FALSE]
+
+bd_xgboost <- local_attributions(m_xgboost,
+                                 data = test_matrix,
+                                 new_observation =  observation_matrix)
+
+plot(bd_xgboost)
+plotD3(bd_xgboost)
 
 ## -----------------------------------------------------------------------------
 library(nnet)
